twostage: Algorithms for 2-stage euclidean real quadratic fields
================================================================

Description
-----------

Algorithms for proving that class-number-one real quadratic fields are 2-stage euclidean, and to find continued fraction expansions in them

License
-------

GPLv2+

Upstream Contact
----------------

- https://pypi.org/project/twostage/
- https://github.com/passagemath/passagemath-pkg-twostage
